@@ -3,12 +3,14 @@ import json
 import logging
 import math
 import time
+import requests
 
 from pymodbus.client.sync import ModbusSerialClient
 from pymodbus.client.sync import ModbusTcpClient
 from pymodbus.constants import Endian
 from pymodbus.exceptions import ModbusException
 from pymodbus.payload import BinaryPayloadDecoder
+from prettytable import PrettyTable
 
 from modpoll.mqtt_task import mqttc_publish
 
@@ -196,7 +198,10 @@ class Poller:
         for ref in self.readableReferences:
             if on_change and ref.val == ref.last_val:
                 continue
-            payload[f'{ref.name}|{ref.unit}'] = ref.val
+            if ref.unit:
+                payload[f'{ref.name}|{ref.unit}'] = ref.val
+            else:
+                payload[f'{ref.name}'] = ref.val
         if timestamp:
             payload['timestamp'] = timestamp
         topic = f"{args.mqtt_topic_prefix}{self.device.name}"
@@ -255,69 +260,80 @@ class Reference:
         self.val = v
 
 
-def load_config(file):
-    with open(file, "r") as f:
-        f.seek(0)
-        csv_reader = csv.reader(f)
-        current_poller = None
-        for row in csv_reader:
-            if not row or len(row) == 0:
-                continue
-            if "poll" in row[0]:
-                name = row[1]
-                devid = int(row[2])
-                reference = int(row[3])
-                size = int(row[4])
-                endian = row[6]
-                if "coil" == row[5]:
-                    functioncode = 1
-                    if size > 2000:  # some implementations don't seem to support 2008 coils/inputs
-                        current_poller = None
-                        log.error(
-                            "Too many coils (max. 2000). Ignoring poller " + row[1] + ".")
-                        continue
-                elif "input_status" == row[5]:
-                    functioncode = 2
-                    if size > 2000:
-                        current_poller = None
-                        log.error(
-                            "Too many inputs (max. 2000). Ignoring poller " + row[1] + ".")
-                        continue
-                elif "holding_register" == row[5]:
-                    functioncode = 3
-                    if size > 123:  # applies to TCP, RTU should support 125 registers. But let's be safe.
-                        current_poller = None
-                        log.error(
-                            "Too many registers (max. 123). Ignoring poller " + row[1] + ".")
-                        continue
-                elif "input_register" == row[5]:
-                    functioncode = 4
-                    if size > 123:
-                        current_poller = None
-                        log.error(
-                            "Too many registers (max. 123). Ignoring poller " + row[1] + ".")
-                        continue
-                else:
-                    log.warning("Unknown function code (" +
-                                row[5] + " ignoring poller " + row[1] + ".")
+def parse_config(csv_reader):
+    current_poller = None
+    for row in csv_reader:
+        if not row or len(row) == 0:
+            continue
+        if "poll" in row[0]:
+            name = row[1]
+            devid = int(row[2])
+            reference = int(row[3])
+            size = int(row[4])
+            endian = row[6]
+            if "coil" == row[5]:
+                functioncode = 1
+                if size > 2000:  # some implementations don't seem to support 2008 coils/inputs
                     current_poller = None
+                    log.error(
+                        "Too many coils (max. 2000). Ignoring poller " + row[1] + ".")
                     continue
-                current_poller = Poller(
-                    name, devid, reference, size, functioncode, endian)
-                pollers.append(current_poller)
-                log.info(f"Added new poller {current_poller.name}, {current_poller.devid}, "
-                         f"{current_poller.reference}, {current_poller.size}")
-            elif "ref" in row[0]:
-                if current_poller:
-                    name = row[1].replace(" ", "_")
-                    unit = row[2]
-                    ref = row[3]
-                    dtype = row[4]
-                    scale = row[5]
-                    current_poller.add_readable_reference(
-                        Reference(name, unit, ref, dtype, scale))
-                else:
-                    log.debug(f"No poller for reference {name}.")
+            elif "input_status" == row[5]:
+                functioncode = 2
+                if size > 2000:
+                    current_poller = None
+                    log.error(
+                        "Too many inputs (max. 2000). Ignoring poller " + row[1] + ".")
+                    continue
+            elif "holding_register" == row[5]:
+                functioncode = 3
+                if size > 123:  # applies to TCP, RTU should support 125 registers. But let's be safe.
+                    current_poller = None
+                    log.error(
+                        "Too many registers (max. 123). Ignoring poller " + row[1] + ".")
+                    continue
+            elif "input_register" == row[5]:
+                functioncode = 4
+                if size > 123:
+                    current_poller = None
+                    log.error(
+                        "Too many registers (max. 123). Ignoring poller " + row[1] + ".")
+                    continue
+            else:
+                log.warning("Unknown function code (" +
+                            row[5] + " ignoring poller " + row[1] + ".")
+                current_poller = None
+                continue
+            current_poller = Poller(
+                name, devid, reference, size, functioncode, endian)
+            pollers.append(current_poller)
+            log.info(f"Added new poller {current_poller.name}, {current_poller.devid}, "
+                     f"{current_poller.reference}, {current_poller.size}")
+        elif "ref" in row[0]:
+            name = row[1].replace(" ", "_")
+            unit = row[2]
+            ref = row[3]
+            dtype = row[4]
+            scale = row[5]
+            if current_poller:
+                current_poller.add_readable_reference(
+                    Reference(name, unit, ref, dtype, scale))
+            else:
+                log.debug(f"No poller for reference {name}.")
+
+
+def load_config(file):
+    try:
+        with requests.Session() as s:
+            response = s.get(file)
+            decoded_content = response.content.decode('utf-8')
+            csv_reader = csv.reader(decoded_content.splitlines(), delimiter=',')
+            parse_config(csv_reader)
+    except requests.RequestException as exception:
+        with open(file, "r") as f:
+            f.seek(0)
+            csv_reader = csv.reader(f)
+            parse_config(csv_reader)
 
 
 def modbus_setup(config):
@@ -327,7 +343,7 @@ def modbus_setup(config):
     log = logging.getLogger(__name__)
     global master
 
-    log.info(f"Loading config from file: {args.config}")
+    log.info(f"Loading config from: {args.config}")
     load_config(args.config)
     if args.rtu:
         if args.rtu_parity == "odd":
@@ -360,10 +376,20 @@ def modbus_poll():
             while time.time() < t + args.interval:
                 time.sleep(0.001)
     master.close()
+    # print out result
+    modbus_print()
     for d in deviceList:
         d.publish_diagnostics()
 
 
+def modbus_print():
+    table = PrettyTable(['name', 'unit', 'reference', 'value'])
+    for r in referenceList:
+        row = [r.name, r.unit, r.reference, r.val]
+        table.add_row(row)
+    print(table)
+
+
 def modbus_export(file):
     with open(file, 'w') as f:
         writer = csv.writer(f)
